@@ -16,6 +16,6 @@
 #
 ##############################################################################
 
-import connector
+from . import connector
 
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
