@@ -15,8 +15,8 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 ##############################################################################
-import manager
-import req_body
-import ucfe_requirement
+from . import manager
+from . import req_body
+from . import ucfe_requirement
 
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
