@@ -99,6 +99,16 @@ class PickingLine(object):
         self.uom_code = None
         self.description_extra = None
 
+class ReceiptLine(object):
+
+    def __init__(self, amount, invoice_indicator, description, quantity, unit_price):
+        self.amount = amount
+        self.invoice_indicator = invoice_indicator
+        self.description = description
+        self.quantity = quantity
+        self.uom_code = 'N/A'
+        self.unit_price = unit_price
+
 
 INVOICE_TYPES = [
     'invoice',
