@@ -130,6 +130,50 @@ class TestUruware(unittest.TestCase):
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
         assert not msg.get('responseMsg')
+    
+    # Ejemplo para e-Factura con cobranza
+    def test_eFact_cfe_invoice_receipt(self):
+
+        # partner factura
+        partner_vat = objects.Vat(215404940014, 2)
+        invoice_partner = objects.Partner("Uruware S.A.")
+        invoice_partner.vat = partner_vat
+        invoice_partner.name = 'Uruware S.A.'
+        invoice_partner.city = 'Montevideo'
+        invoice_partner.street = 'Bv.Espana 2579'
+        invoice_partner.country_code = 'UY'
+        invoice_partner.country = 'Uruguay'
+        invoice_partner.email = 'lbaldi@openpyme.com.ar'
+
+        # creamos linea de pago
+        line1 = objects.ReceiptLine(10000, 6, "Pago de factura", 1, 10000)
+
+        refund_invoice = objects.Invoice('invoice')
+        refund_invoice.cfe_code = '111'
+        refund_invoice.date = '2015-01-31'
+        refund_invoice.cfe_serial = 'A'
+        refund_invoice.cfe_number = '1234567'
+
+        refund = objects.Object()
+        refund.refund_reason = ''
+        refund.refund_invoices = [refund_invoice]
+
+        # creamos factura
+        comprobante = objects.Invoice('invoice')
+        comprobante.cfe_code = '111'
+        comprobante.date = '2015-01-31'
+        comprobante.partner = invoice_partner
+        comprobante.cfe_type = 'eFact'
+        comprobante.invoice_lines = [line1]
+        comprobante.refund_info = refund
+        comprobante.currency = 'UYU'
+        comprobante.include_tax = True
+        comprobante.payment_method = "1"
+        comprobante.own_collection = True
+
+        msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
+
+        assert not msg.get('responseMsg')
 
     # Ejemplo para e-Factura con impuesto de exportacion
     def test_eFact_cfe_invoice_with_tax_exportation(self):
